#
# MATHEMATICS OF INFRASTRUCTURE PLANNING SS 2012
# Ralf Borndoerfer & Martin Groetschel
# 06/2012
#
# Vehicle Scheduling
#
#------------------------------------------------------------------------------
#
# The data are:
#
# - A  	   arcs: set of all arcs, defined by tail, head, and depot
# - E  	   deadheads: set of all deadhead trips corresponding to the arcs
# - V  	   nodes: set of all nodes, corresponding to timetabled trips plus an
#      	   artificial depot node 0 
# - W  	   trips: set of all timetabled trips
# - D  	   depots: set of depots
# - c  	   costs: array of arc costs
# - F  	   flows: set of relaxed individual flow constraints
# - lambda duals: multipliers for relaxed individual flow constraints
# - s      source/sink: artificial depot node to start and end rotations
#
# The variables are:
#
# - x      flow
# - y      fleet: depot fleet size
# - z      fleet: total fleet size
# - r      residuals: residuals of relaxed individual flow constraints
#
#------------------------------------------------------------------------------

param s := 0;

set A := { read "arcs.dat" as "<3n,4n,5n>" comment "#" };
set E := proj(A,<1,2>);
set V := proj(A,<1>) union proj(A,<2>);
set W := V without { s };
set D := proj(A,<3>);
set F := V cross D;

do print "# depots           = ", card(D);
do print "# timetabled trips = ", card(W);
do print "# nodes            = ", card(V);
do print "# deadheads        = ", card(E);
do print "# arcs             = ", card(A);

param c[A] := read "arcs.dat" as "<3n,4n,5n> 6n" comment "#";

param lambda[F] := read "flowduals.dat" as "<2n,3n> 4n" comment "#" default 0;

# variables

# objective

# constraints
